@@ -674,17 +674,15 @@ void XmlRpcMethodTest::testGatherStoppedDownload()
   std::vector<gid_t> followedBy;
   followedBy.push_back(3);
   followedBy.push_back(4);
-  SharedHandle<DownloadResult> d
-    (new DownloadResult(1,
-                        fileEntries,
-                        false,
-                        UINT64_MAX,
-                        1000,
-                        downloadresultcode::FINISHED,
-                        followedBy,
-                        2,
-                        SharedHandle<Option>(),
-                        SharedHandle<MetadataInfo>()));
+  SharedHandle<DownloadResult> d(new DownloadResult());
+  d->gid = 1;
+  d->fileEntries = fileEntries;
+  d->inMemoryDownload = false;
+  d->sessionDownloadLength = UINT64_MAX;
+  d->sessionTime = 1000;
+  d->result = downloadresultcode::FINISHED;
+  d->followedBy = followedBy;
+  d->belongsTo = 2;
   BDE entry = BDE::dict();
   gatherStoppedDownload(entry, d);
 
@@ -698,7 +696,7 @@ void XmlRpcMethodTest::testGatherProgressCommon()
   SharedHandle<DownloadContext> dctx(new DownloadContext(0, 0,"aria2.tar.bz2"));
   std::string uris[] = { "http://localhost/aria2.tar.bz2" };
   dctx->getFirstFileEntry()->addUris(vbegin(uris), vend(uris));
-
+  dctx->setDir(_option->get(PREF_DIR));
   SharedHandle<RequestGroup> group(new RequestGroup(_option));
   group->setDownloadContext(dctx);
   std::vector<SharedHandle<RequestGroup> > followedBy;
